@@ -1,13 +1,14 @@
 from peek_plugin_chat._private.PluginNames import chatFilt
 from peek_plugin_chat._private.PluginNames import chatObservableName
-from peek_plugin_chat._private.server.tuple_providers.ChatTupleProvider import \
-    ChatTupleProvider
+from peek_plugin_chat._private.server.tuple_providers.ChatTupleProvider import (
+    ChatTupleProvider,
+)
 from peek_plugin_chat._private.storage.ChatTuple import ChatTuple
 from vortex.handler.TupleDataObservableHandler import TupleDataObservableHandler
 
 
 def makeTupleDataObservableHandler(ormSessionCreator):
-    """" Make Tuple Data Observable Handler
+    """ " Make Tuple Data Observable Handler
 
     This method creates the observable object, registers the tuple providers and then
     returns it.
@@ -18,11 +19,12 @@ def makeTupleDataObservableHandler(ormSessionCreator):
 
     """
     tupleObservable = TupleDataObservableHandler(
-        observableName=chatObservableName,
-        additionalFilt=chatFilt)
+        observableName=chatObservableName, additionalFilt=chatFilt
+    )
 
     # Register TupleProviders here
-    tupleObservable.addTupleProvider(ChatTuple.tupleName(),
-                                     ChatTupleProvider(ormSessionCreator))
+    tupleObservable.addTupleProvider(
+        ChatTuple.tupleName(), ChatTupleProvider(ormSessionCreator)
+    )
 
     return tupleObservable
